@@ -65,8 +65,8 @@ impl ParseFromMultipartField for String {
 }
 
 impl ToJSON for String {
-    fn to_json(&self) -> Value {
-        Value::String(self.clone())
+    fn to_json(&self) -> Option<Value> {
+        Some(Value::String(self.clone()))
     }
 }
 
@@ -106,7 +106,7 @@ impl<'a> Type for &'a str {
 }
 
 impl<'a> ToJSON for &'a str {
-    fn to_json(&self) -> Value {
-        Value::String(self.to_string())
+    fn to_json(&self) -> Option<Value> {
+        Some(Value::String(self.to_string()))
     }
 }
